==> sigmund-0.20.0.tar.gz: sigmund-0.20.0/sigmund/static/terms.md <==
[TOC]


# Privacy and security

## Does Sigmund use cookies and trackers?

Sigmund uses cookies to manage your log in. jsdelivr.net and cloudfare.com are used as content-delivery-network (CDN) services. No third-party trackers are used.


## Where is the Sigmund server located?

The Sigmund server is physically located within the European Union, and is hosted by TransIP.


## How secure is Sigmund?

Sigmund uses encryption for all network traffic. Messages and attachments are encrypted (see [About](/about)).


## How is data on Sigmund backed up?

Sigmund does *not* guarantee that data will be preserved. We do not have the capacity to help troubleshoot or recover lost data.


## What user data is stored on Sigmund?

A user account on Sigmund only contains a username, encrypted message and attachment data, and limited information necessary for subscriptions.


## Who owns user data on Sigmund?

The user owns his or her own data.


## How do I delete my user data on Sigmund?

A user can delete all conversations and attachments on Sigmund through the Conversations and Attachments option in the user menu.


## What does Sigmund do with user data?

Nothing. User data is stored solely for the purpose of providing the intended service (i.e. question answering).


# Terms of use

## Usage limits

There is currently an hourly limit of 100,000 tokens per user. When this limit is exceeded, you need to wait for (at most) an hour until you can use Sigmund again. The hourly limit may be adjusted once we get a better picture of what kind of limits are needed to avoid excessive use.


## Availability

As electronic services are subject to interruption or breakdown, access to  Sigmund is provided on an “as is” and “as available” basis only.


## Communication of changes

We will make a reasonable effort to notify users in advance of any changes related to availability, terms of use, or privacy and ethics. However, we cannot guarantee this. Specifically, for security, technical, maintenance, legal or regulatory reasons, or due to any breach of the terms of use, we may withdraw this service at any time and without advance notice, or impose restrictions on the use of Sigmund. If such changes negatively impact user experience, users will be offered a refund for the remaining period (after the change) of their subscription.


## Limitation of liability

It is your own responsibility to ensure that your use of Sigmund complies with all relevant regulations, which includes (but may not be limited to) regulations of the European Union, regulations of The Netherlands, and regulations of the location where the user is based.

We are not liable for any losses, damages, claims and expenses whatsoever that result from using Sigmund.


## Abusive and illegal content

Abusive accounts will be suspended without advance notice. Here, ‘abuse’ includes (but is not limited to) generation of illegal material.


## Subscriptions and payments

Subscriptions and payments are handled through Stripe. If the monthly subscription fee changes, you will be notified in advance. You can cancel your subscription at any time, in which case the subscription ends at the end of the next billing cycle.


## Who runs Sigmund?

Sigmund is a product of CogSci (KvK 67290965), which is registered in The Netherlands. You can reach us by email at <a href="mailto:professional@cogsci.nl">professional@cogsci.nl</a>.

==> sigmund-1.8.0.tar.gz: sigmund-1.8.0/sigmund/static/terms.md <==
[TOC]


# Privacy and security

## Does Sigmund use cookies and trackers?

Sigmund uses cookies to manage your log in. jsdelivr.net and cloudfare.com are used as content-delivery-network (CDN) services. No third-party trackers are used.


## Where is the Sigmund server located?

The Sigmund server is physically located within the European Union, and is hosted by TransIP.


## How secure is Sigmund?

Sigmund uses encryption for all network traffic. Messages are encrypted in a way that allows no-one, not even Sigmund's administrators, to read along.


## How is data on Sigmund backed up?

Sigmund does *not* guarantee that data will be preserved. We do not have the capacity to help troubleshoot or recover lost data.


## What user data is stored on Sigmund?

A user account on Sigmund only contains a username, encrypted messages, and limited information necessary for subscriptions.


## Who owns user data on Sigmund?

The user owns his or her own data.


## How do I delete my user data on Sigmund?

A user can delete all conversations and attachments on Sigmund through the Conversations and Attachments option in the user menu.


## What does Sigmund do with user data?

Nothing. User data is stored solely for the purpose of providing the intended service (i.e. question answering).


# Terms of use

## Usage limits

There is an hourly limit of tokens per user to avoid abuse. This limit is so high that you are unlikely to run into it during normal use. If you have nevertheless exceeded the limit, you simply need to wait for (at most) an hour until you can use Sigmund again.


## Availability

As electronic services are subject to interruption or breakdown, access to  Sigmund is provided on an “as is” and “as available” basis only.


## Communication of changes

We will make a reasonable effort to notify users in advance of any changes related to availability, terms of use, or privacy and ethics. However, we cannot guarantee this. Specifically, for security, technical, maintenance, legal or regulatory reasons, or due to any breach of the terms of use, we may withdraw this service at any time and without advance notice, or impose restrictions on the use of Sigmund. If such changes negatively impact user experience, users will be offered a refund for the remaining period (after the change) of their subscription.


## Limitation of liability

It is your own responsibility to ensure that your use of Sigmund complies with all relevant regulations, which includes (but may not be limited to) regulations of the European Union, regulations of The Netherlands, and regulations of the location where the user is based.

We are not liable for any losses, damages, claims and expenses whatsoever that result from using Sigmund.


## Abusive and illegal content

Abusive accounts will be suspended without advance notice. Here, ‘abuse’ includes (but is not limited to) generation of illegal material.


## Subscriptions and payments

Subscriptions and payments are handled through Stripe. If the monthly subscription fee changes, you will be notified in advance. You can cancel your subscription at any time, in which case the subscription ends at the end of the next billing cycle.


## Who runs Sigmund?

Sigmund is a product of CogSci (KvK 67290965), which is registered in The Netherlands. You can reach us by email at <a href="mailto:professional@cogsci.nl">professional@cogsci.nl</a>.
